==> openGion7.2.5.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GEA04S.sql <==
/****************************************************************************/
/* GEA04 ( ｺｰﾄﾞ定義 )                                                       */
/*                                                                          */
/* Created : 2018/09/28 16:03:23                                            */
/****************************************************************************/

CREATE TABLE GEA04 (
   SYSTEM_ID        VARCHAR  (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , CLM              VARCHAR  (   30 )                   NOT NULL            /*  20 項目         */
 , CODE             VARCHAR  (   30 )                   NOT NULL            /*  30 ｺｰﾄﾞ         */
 , SEQNO            INTEGER                 DEFAULT 0   NOT NULL            /*  40 表示順       */
 , CDKH             VARCHAR  (    1 )                                       /*  50 改廃ｺｰﾄﾞ     */
 , KBSAKU           VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /*  60 作成区分     */
 , RELEASE_NOTES    VARCHAR  (  120 )                                       /*  70 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR  (   20 )                                       /*  80 設変番号     */
 , CODEGRP          VARCHAR  (   20 )                                       /*  90 ｺｰﾄﾞｸﾞﾙｰﾌﾟ   */
 , COMMENTS         VARCHAR  (  500 )                                       /* 100 ｺﾒﾝﾄ         */
 , CODELVL          VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 110 階層         */
 , CODE_PARAM       VARCHAR  (  200 )                                       /* 120 ｺｰﾄﾞﾊﾟﾗﾒｰﾀ   */
 , ROLES            VARCHAR  ( 2000 )                                       /* 130 ﾛｰﾙｽﾞ        */
 , UNIQ             IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR  (   14 )                                       /* 820 登録日時     */
 , PGSET            VARCHAR  (   10 )                                       /* 830 作成PG       */
 , PGPSET           VARCHAR  (   10 )                                       /* 840 作成親PG     */
 , USRSET           VARCHAR  (   10 )                                       /* 850 作成者       */
 , DYUPD            VARCHAR  (   14 )                                       /* 860 更新日時     */
 , PGUPD            VARCHAR  (   10 )                                       /* 870 更新PG       */
 , PGPUPD           VARCHAR  (   10 )                                       /* 880 更新親PG     */
 , USRUPD           VARCHAR  (   10 )                                       /* 890 更新者       */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GEA04S.sql <==
/****************************************************************************/
/* GEA04 ( ｺｰﾄﾞ定義 )                                                       */
/*                                                                          */
/* Created : 2020/12/16 08:13:57                                            */
/****************************************************************************/

CREATE TABLE GEA04 (
   SYSTEM_ID        VARCHAR  (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , CLM              VARCHAR  (   30 )                   NOT NULL            /*  20 項目         */
 , CODE             VARCHAR  (   30 )                   NOT NULL            /*  30 ｺｰﾄﾞ         */
 , SEQNO            INTEGER                 DEFAULT 0   NOT NULL            /*  40 表示順       */
 , CDKH             VARCHAR  (    1 )                                       /*  50 改廃ｺｰﾄﾞ     */
 , KBSAKU           VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /*  60 作成区分     */
 , RELEASE_NOTES    VARCHAR  (  120 )                                       /*  70 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR  (   20 )                                       /*  80 設変番号     */
 , CODEGRP          VARCHAR  (   20 )                                       /*  90 ｺｰﾄﾞｸﾞﾙｰﾌﾟ   */
 , COMMENTS         VARCHAR  (  500 )                                       /* 100 ｺﾒﾝﾄ         */
 , CODELVL          VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 110 階層         */
 , CODE_PARAM       VARCHAR  (  200 )                                       /* 120 ｺｰﾄﾞﾊﾟﾗﾒｰﾀ   */
 , ROLES            VARCHAR  ( 2000 )                                       /* 130 ﾛｰﾙｽﾞ        */
 , UNIQ             IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR  (   14 )                                       /* 820 作成日時     */
 , PGSET            VARCHAR  (   10 )                                       /* 830 作成PG       */
 , PGPSET           VARCHAR  (   10 )                                       /* 840 作成親PG     */
 , USRSET           VARCHAR  (   10 )                                       /* 850 作成者       */
 , DYUPD            VARCHAR  (   14 )                                       /* 860 更新日時     */
 , PGUPD            VARCHAR  (   10 )                                       /* 870 更新PG       */
 , PGPUPD           VARCHAR  (   10 )                                       /* 880 更新親PG     */
 , USRUPD           VARCHAR  (   10 )                                       /* 890 更新者       */
);
